#!/usr/bin/python
# coding=utf-8 
# terminal.py - Programm zur Übergabe von Daten über den UART
#---------------------------------------------------------------------


# Bibliotheken
import os, sys, sqlite3, time, serial
import tornado.httpserver, tornado.websocket, tornado.ioloop, tornado.web
import datetime, json


# 1. Schritt: UART konfigurieren und Schnittstelle öffnen
ser = serial.Serial("/dev/ttyAMA0")
ser.flushInput()
ser.baudrate = 9600
# ser.stopbits = 1
ser.timeout = 1

print ("UART konfiguriert.")

# 2. Schritt
# Hauptroutine - WebSocket öffnen und empfangenen Daten austauschen

print ("Warte auf Verbindung mit WEB-Interface.")

class WSHandler(tornado.websocket.WebSocketHandler):

    def check_origin(self, origin):
        return True
    
    def open(self):
        self.connected = True
        print ("Verbindung mit WEB-Interface aufgebaut.")
        self.timeout_loop()
 
    def on_message(self, message):
        print ("Übergabewert von WEB-Interface: ", message)
    
        uebergabeWert = message + "\n" #fügt einen Zeilenumbruch an 

        if message == "shutdown" : 
            print ("RasPi Herunterfahren") 
            ser.close() 
            os.system("sudo shutdown -h now") 
            sys.exit() 
    
        elif message == "reboot" : 
            print ("RasPi Neustart") 
            ser.close() 
            os.system("sudo shutdown -r now") 
            sys.exit() 
            
        else:   
            print ("Daten werden an UART übergeben")
            #ser.write(uebergabeWert)

                    
    def on_close(self):
        self.connected = False
        print ("Verbindung zum WEB-Interface geschlossen.")


    def timeout_loop(self):
        global reset
        if self.connected:
            ser.flushInput()

            daten = ser.readline()
            
            if len(daten) > 0:
                print ("Empfang von UART: ",daten)
                self.write_message(daten)

            else:
                print ("Keine Daten von UART gelesen")

            tornado.ioloop.IOLoop.instance().add_timeout(datetime.timedelta(seconds=.01), self.timeout_loop)

application = tornado.web.Application([(r'/ws', WSHandler),])

if __name__ == "__main__":
    http_server = tornado.httpserver.HTTPServer(application)
    http_server.listen(8888)
    tornado.ioloop.IOLoop.instance().start()

# Schließung UART
ser.close()
# Programm Ende
sys.exit()
